from enum import IntEnum


class CollectTreasureSliceType(IntEnum):

    Slice1 = 1,
    Slice3 = 3,
    Slice5 = 5,
    Slice10 = 10,
    Slice12 = 12,
    Slice24 = 24,
    Slice36 = 36,
    Slice64 = 64,
    Slice99 = 99,